@@ -16,34 +16,36 @@ from opera_tosca_parser.parser.utils.location import Location
 
 
 class CsarMeta:
-    SUPPORTED_CSAR_VERSIONS = {"2.0"}
+    SUPPORTED_META_FILE_VERSIONS = {"1.1"}
+    SUPPORTED_CSAR_VERSIONS = {"1.1"}
     METADATA_PATH = "TOSCA-Metadata/TOSCA.meta"
 
     KEY_NAME = "Name"
     KEY_CONTENT_TYPE = "Content-Type"
+    KEY_TOSCA_META_FILE_VERSION = "TOSCA-Meta-File-Version"
     KEY_CSAR_VERSION = "CSAR-Version"
     KEY_CREATED_BY = "Created-By"
     KEY_ENTRY_DEFINITIONS = "Entry-Definitions"
-    KEY_OTHER_DEFINITIONS = "Other-Definitions"
 
-    REQUIRED_KEYS = {KEY_CSAR_VERSION, KEY_CREATED_BY}
+    REQUIRED_KEYS = {KEY_TOSCA_META_FILE_VERSION, KEY_CSAR_VERSION, KEY_CREATED_BY}
 
-    def __init__(self, name: Optional[str], content_type: Optional[str], csar_version: str, created_by: str,
-                 entry_definitions: Optional[str], other_definitions: Optional[str]):
+    def __init__(self, name: Optional[str], content_type: Optional[str], tosca_meta_file_version: str,
+                 csar_version: str, created_by: str, entry_definitions: Optional[str]):
         """
         Construct CsarMeta object
         :param name: Name key
         :param content_type: Content-Type key
+        :param tosca_meta_file_version: TOSCA-Meta-File-Version key
         :param csar_version: CSAR-Version key
         :param created_by: Created-By key
         :param entry_definitions: Entry-Definitions key
         """
         self.name = name
         self.content_type = content_type
+        self.tosca_meta_file_version = tosca_meta_file_version
         self.csar_version = csar_version
         self.created_by = created_by
         self.entry_definitions = entry_definitions
-        self.other_definitions = entry_definitions
 
     @classmethod
     def parse(cls, contents: str) -> CsarMeta:
@@ -52,7 +54,7 @@ class CsarMeta:
         :param contents: Metadata contents
         :return: CsarMeta object
         """
-        # TODO: The meta format is not YAML, but it"s close enough to parse a simple file.
+        # FIXME: the meta format is not yaml, but it"s close enough to parse a simple file
         parsed = yaml.safe_load(contents)
 
         for req in CsarMeta.REQUIRED_KEYS:
@@ -66,13 +68,20 @@ class CsarMeta:
                 f"{CsarMeta.SUPPORTED_CSAR_VERSIONS}\".", Location(CsarMeta.METADATA_PATH, 0, 0)
             )
 
+        tmf_version = str(parsed[CsarMeta.KEY_TOSCA_META_FILE_VERSION])
+        if tmf_version not in CsarMeta.SUPPORTED_META_FILE_VERSIONS:
+            raise ParseError(
+                f"{CsarMeta.KEY_TOSCA_META_FILE_VERSION} {tmf_version} is not supported. Supported versions: "
+                f"{CsarMeta.SUPPORTED_META_FILE_VERSIONS}\".", Location(CsarMeta.METADATA_PATH, 0, 0)
+            )
+
         result = CsarMeta(
             name=parsed.get(CsarMeta.KEY_NAME),
             content_type=parsed.get(CsarMeta.KEY_CONTENT_TYPE),
+            tosca_meta_file_version=tmf_version,
             csar_version=csar_version,
             created_by=parsed[CsarMeta.KEY_CREATED_BY],
             entry_definitions=parsed.get(CsarMeta.KEY_ENTRY_DEFINITIONS),
-            other_definitions=parsed.get(CsarMeta.KEY_OTHER_DEFINITIONS),
         )
 
         return result
@@ -85,10 +94,10 @@ class CsarMeta:
         ordered_fields = [
             (CsarMeta.KEY_NAME, self.name),
             (CsarMeta.KEY_CONTENT_TYPE, self.content_type),
+            (CsarMeta.KEY_TOSCA_META_FILE_VERSION, self.tosca_meta_file_version),
             (CsarMeta.KEY_CSAR_VERSION, self.csar_version),
             (CsarMeta.KEY_CREATED_BY, self.created_by),
-            (CsarMeta.KEY_ENTRY_DEFINITIONS, self.entry_definitions),
-            (CsarMeta.KEY_OTHER_DEFINITIONS, self.other_definitions)
+            (CsarMeta.KEY_ENTRY_DEFINITIONS, self.entry_definitions)
         ]
 
         return "\n".join(f"{k}: {v}" for k, v in ordered_fields if v is not None)
@@ -101,10 +110,10 @@ class CsarMeta:
         return {
             CsarMeta.KEY_NAME: self.name,
             CsarMeta.KEY_CONTENT_TYPE: self.content_type,
+            CsarMeta.KEY_TOSCA_META_FILE_VERSION: self.tosca_meta_file_version,
             CsarMeta.KEY_CSAR_VERSION: self.csar_version,
             CsarMeta.KEY_CREATED_BY: self.created_by,
-            CsarMeta.KEY_ENTRY_DEFINITIONS: self.entry_definitions,
-            CsarMeta.KEY_OTHER_DEFINITIONS: self.other_definitions
+            CsarMeta.KEY_ENTRY_DEFINITIONS: self.entry_definitions
         }
 
 
@@ -430,7 +439,7 @@ class DirCloudServiceArchive(CloudServiceArchive):
 
                 if meta is None and len(root_yaml_files) != 1:
                     raise ParseError(
-                        f"You did not specify the CSAR TOSCA entrypoint with '-t/--service-template' option. Therefore "
+                        f"You didn't specify the CSAR TOSCA entrypoint with '-t/--service-template' option. Therefore "
                         f"there should be one YAML file in the root of the CSAR to select it as the entrypoint. More "
                         f"than one YAML has been found: {list(map(str, root_yaml_files))}. Please select one of the "
                         f"files as the CSAR entrypoint using '-t/--service-template' flag or remove all the excessive "
@@ -471,7 +480,8 @@ class DirCloudServiceArchive(CloudServiceArchive):
                     # create TOSCA-Metadata/TOSCA.meta file using the specified
                     # TOSCA service template or directory root YAML file
                     content = (
-                        f"CSAR-Version: 2.0\n"
+                        f"TOSCA-Meta-File-Version: 1.1\n"
+                        f"CSAR-Version: 1.1\n"
                         f"Created-By: xOpera TOSCA orchestrator\n"
                         f"Entry-Definitions: {service_template}\n"
                     )
