@@ -1,4 +1,4 @@
-from opera_tosca_parser.parser.tosca.v_2_0.definitions.relationship_type import RelationshipType
+from opera_tosca_parser.parser.tosca.v_1_3.definitions.relationship_type import RelationshipType
 
 
 class TestParse:
@@ -14,7 +14,7 @@ class TestParse:
             properties: {}
             attributes: {}
             interfaces: {}
-            valid_capability_types: [ a, b, c ]
+            valid_target_types: [ a, b, c ]
             """
         ))
 
