@@ -1,7 +1,9 @@
 import pytest
 
 from opera_tosca_parser.error import ParseError
-from opera_tosca_parser.parser.tosca.v_2_0.definitions.requirement_assignment import RequirementAssignment
+from opera_tosca_parser.parser.tosca.v_1_3.definitions.requirement_assignment import (
+    RequirementAssignment,
+)
 from opera_tosca_parser.parser.yaml.node import Node
 
 
@@ -32,7 +34,7 @@ class TestParse:
             node: some_node_template
             relationship: some_relationship_template
             node_filter: {}
-            count: 2
+            occurrences: [ 2, 3 ]
             """
         ))
 
