@@ -1,7 +1,7 @@
 import pytest
 
 from opera_tosca_parser.error import ParseError
-from opera_tosca_parser.parser.tosca.v_1_3.definitions.artifact_definition import ArtifactDefinition
+from opera_tosca_parser.parser.tosca.v_2_0.definitions.artifact_definition import ArtifactDefinition
 from opera_tosca_parser.parser.yaml.node import Node
 
 
@@ -15,7 +15,7 @@ class TestNormalize:
         obj = ArtifactDefinition.normalize(Node("string"))
 
         assert obj.bare == {
-            "type": "tosca.artifacts.File",
+            "type": "File",
             "file": "string",
         }
 
