@@ -1,4 +1,4 @@
-from opera_tosca_parser.parser.tosca.v_1_3.definitions.capability_definition import CapabilityDefinition
+from opera_tosca_parser.parser.tosca.v_2_0.definitions.capability_definition import CapabilityDefinition
 
 
 class TestParse:
@@ -10,8 +10,7 @@ class TestParse:
             description: Some text
             properties: {}
             attributes: {}
-            valid_source_types: []
-            occurrences: [ 4, UNBOUNDED ]
+            valid_source_node_types: []
             """
         ))
 
